cal.EventType (Calendar entry type) — amici1

# `cal.EventType` (Calendar entry type)

EventType(id, ref, seqno, name, attach_to_email, email_template, description, is_appointment, all_rooms, locks_user, force_guest_states, fill_presences, start_date, event_label, max_conflicting, max_days, transparent, planner_column, default_duration, event_label_de, event_label_fr, name_de, name_fr)

Master tables : cal.EventTypes (Calendar entry types)

Slave tables : cal.EntriesByType (Calendar entries)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Reference (ref) : The reference. This must be either empty or unique.

- No. (seqno) : The sequence number of this item with its parent.

- Designation (name) : See `<lino.utils.mldbc.fields.BabelCharField: name>`.

- Attach to email (attach_to_email) : Whether the printable file should be attached to the email when creating an email from a mailable of this type.

- Email template (email_template) : The name of the file to be used as template when creating an email from a mailable of this type.

- Description (description) : See `<lino.core.fields.RichTextField: description>`.

- Appointment (is_appointment) : Whether entries of this type are considered „appointments“ (i.e. whose time and place have been agreed upon with other users or external parties).

- Locks all rooms (all_rooms) : See `<django.db.models.fields.BooleanField: all_rooms>`.

- Locks the user (locks_user) : Whether calendar entries of this type make the user unavailable for other locking events at the same time.

- Automatic presences (force_guest_states) : Whether presence states should be forced to those defined by the entry state.

- Fill guests (fill_presences) : Whether guests should be automatically filled for calendar entries of this type.

- Start date (start_date) : See `<django.db.models.fields.DateField: start_date>`.

- Entry label (event_label) : Default text for summary of new entries.

- Simultaneous entries (max_conflicting) : How many conflicting events should be tolerated.

- Maximum days (max_days) : The maximal number of days allowed as duration. 0 means no limit.

- Transparent (transparent) : Allow entries of this type to conflict with other events.

- Planner column (planner_column) : See `<lino.core.choicelists.ChoiceListField: planner_column>`.

- Default duration (default_duration) : An optional default duration for calendar entries of this type.

- Entry label (de) (event_label_de) : See `<django.db.models.fields.CharField: event_label_de>`.

- Entry label (fr) (event_label_fr) : See `<django.db.models.fields.CharField: event_label_fr>`.

- Designation (de) (name_de) : See `<django.db.models.fields.CharField: name_de>`.

- Designation (fr) (name_fr) : See `<django.db.models.fields.CharField: name_fr>`.

- Name (name_column) : See `lino_xl.lib.cal.models.EventType.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.cal.models.EventType.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.cal.models.EventType.overview`.

- Move (move_buttons) : Displays buttons for certain actions on this row:

Referenced from cal.Event.event_type, cal.EventPolicy.event_type, cal.RecurrentEvent.event_type, courses.Line.event_type, system.SiteConfig.default_event_type, users.User.event_type

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
ref | Reference | The reference. This must be either empty or unique.
seqno | No. | The sequence number of this item with its parent.
name | Designation |
attach_to_email | Attach to email | Whether the printable file should be attached to the email when creating an email from a mailable of this type.
email_template | Email template | The name of the file to be used as template when creating an email from a mailable of this type.
description | Description |
is_appointment | Appointment | Whether entries of this type are considered „appointments“ (i.e. whose time and place have been agreed upon with other users or external parties).
all_rooms | Locks all rooms |
locks_user | Locks the user | Whether calendar entries of this type make the user unavailable for other locking events at the same time.
force_guest_states | Automatic presences | Whether presence states should be forced to those defined by the entry state.
fill_presences | Fill guests | Whether guests should be automatically filled for calendar entries of this type.
start_date | Start date |
event_label | Entry label | Default text for summary of new entries.
max_conflicting | Simultaneous entries | How many conflicting events should be tolerated.
max_days | Maximum days | The maximal number of days allowed as duration. 0 means no limit.
transparent | Transparent | Allow entries of this type to conflict with other events.
planner_column | Planner column |
default_duration | Default duration | An optional default duration for calendar entries of this type.
event_label_de | Entry label (de) |
event_label_fr | Entry label (fr) |
name_de | Designation (de) |
name_fr | Designation (fr) |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |
move_buttons | Move | Displays buttons for certain actions on this row: